@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Free Mandatory Access Control.
  *
- * Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.4   2008/09/03
+ * Version: 1.6.7+   2009/04/10
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -37,6 +37,56 @@ static inline void module_put(struct module *module)
 }
 #endif
 
+/**
+ * ccs_encode: Encode binary string to ascii string.
+ *
+ * @str: String in binary format.
+ *
+ * Returns pointer to @str in ascii format on success, NULL otherwise.
+ *
+ * This function uses ccs_alloc(), so caller must ccs_free() if this function
+ * didn't return NULL.
+ */
+static char *ccs_encode(const char *str)
+{
+	int len = 0;
+	const char *p = str;
+	char *cp;
+	char *cp0;
+	if (!p)
+		return NULL;
+	while (*p) {
+		const unsigned char c = *p++;
+		if (c == '\\')
+			len += 2;
+		else if (c > ' ' && c < 127)
+			len++;
+		else
+			len += 4;
+	}
+	len++;
+	cp = ccs_alloc(len, false);
+	if (!cp)
+		return NULL;
+	cp0 = cp;
+	p = str;
+	while (*p) {
+		const unsigned char c = *p++;
+		if (c == '\\') {
+			*cp++ = '\\';
+			*cp++ = '\\';
+		} else if (c > ' ' && c < 127) {
+			*cp++ = c;
+		} else {
+			*cp++ = '\\';
+			*cp++ = (c >> 6) + '0';
+			*cp++ = ((c >> 3) & 7) + '0';
+			*cp++ = (c & 7) + '0';
+		}
+	}
+	return cp0;
+}
+
 /* Keywords for mount restrictions. */
 
 /* Allow to call 'mount --bind /source_dir /dest_dir' */
@@ -55,11 +105,11 @@ static inline void module_put(struct module *module)
 #define MOUNT_MAKE_SHARED_KEYWORD                        "--make-shared"
 
 /* Structure for "allow_mount" keyword. */
-struct mount_entry {
+struct ccs_mount_entry {
 	struct list1_head list;
-	const struct path_info *dev_name;
-	const struct path_info *dir_name;
-	const struct path_info *fs_type;
+	const struct ccs_path_info *dev_name;
+	const struct ccs_path_info *dir_name;
+	const struct ccs_path_info *fs_type;
 	unsigned long flags;
 	bool is_deleted;
 };
@@ -72,11 +122,11 @@ static void put_filesystem(struct file_system_type *fs)
 }
 #endif
 
-/* The list for "struct mount_entry". */
-static LIST1_HEAD(mount_list);
+/* The list for "struct ccs_mount_entry". */
+static LIST1_HEAD(ccs_mount_list);
 
 /**
- * update_mount_acl - Update "struct mount_entry" list.
+ * ccs_update_mount_acl - Update "struct ccs_mount_entry" list.
  *
  * @dev_name:  Name of device file.
  * @dir_name:  Name of mount point.
@@ -86,18 +136,20 @@ static LIST1_HEAD(mount_list);
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int update_mount_acl(const char *dev_name, const char *dir_name,
-			    const char *fs_type, const unsigned long flags,
-			    const bool is_delete)
+static int ccs_update_mount_acl(const char *dev_name, const char *dir_name,
+				const char *fs_type, const unsigned long flags,
+				const bool is_delete)
 {
 	struct file_system_type *type = NULL;
-	struct mount_entry *new_entry;
-	struct mount_entry *ptr;
-	const struct path_info *fs;
-	const struct path_info *dev;
-	const struct path_info *dir;
+	struct ccs_mount_entry *new_entry;
+	struct ccs_mount_entry *ptr;
+	const struct ccs_path_info *fs;
+	const struct ccs_path_info *dev;
+	const struct ccs_path_info *dir;
 	static DEFINE_MUTEX(lock);
 	int error = -ENOMEM;
+	if (!ccs_is_correct_path(fs_type, 0, 0, 0, __func__))
+		return -EINVAL;
 	fs = ccs_save_name(fs_type);
 	if (!fs)
 		return -EINVAL;
@@ -120,7 +172,7 @@ static int update_mount_acl(const char *dev_name, const char *dir_name,
 	if (!dev || !dir)
 		return -ENOMEM;
 	mutex_lock(&lock);
-	list1_for_each_entry(ptr, &mount_list, list) {
+	list1_for_each_entry(ptr, &ccs_mount_list, list) {
 		if (ptr->flags != flags ||
 		    ccs_pathcmp(ptr->dev_name, dev) ||
 		    ccs_pathcmp(ptr->dir_name, dir) ||
@@ -149,7 +201,7 @@ static int update_mount_acl(const char *dev_name, const char *dir_name,
 	new_entry->dir_name = dir;
 	new_entry->fs_type = fs;
 	new_entry->flags = flags;
-	list1_add_tail_mb(&new_entry->list, &mount_list);
+	list1_add_tail_mb(&new_entry->list, &ccs_mount_list);
 	error = 0;
 	ptr = new_entry;
  update:
@@ -187,7 +239,7 @@ static int update_mount_acl(const char *dev_name, const char *dir_name,
 }
 
 /**
- * print_success - Print success messages.
+ * ccs_print_success - Print success messages.
  *
  * @dev_name: Name of device file.
  * @dir_name: Name of mount point.
@@ -197,9 +249,9 @@ static int update_mount_acl(const char *dev_name, const char *dir_name,
  *
  * Returns nothing.
  */
-static void print_success(const char *dev_name, const char *dir_name,
-			  const char *type, const unsigned long flags,
-			  const int need_dev)
+static void ccs_print_success(const char *dev_name, const char *dir_name,
+			      const char *type, const unsigned long flags,
+			      const int need_dev)
 {
 	if (need_dev > 0) {
 		printk(KERN_DEBUG "SAKURA-NOTICE: "
@@ -228,54 +280,45 @@ static void print_success(const char *dev_name, const char *dir_name,
 }
 
 /**
- * print_error - Print error messages.
+ * ccs_print_error - Print error messages.
  *
- * @dev_name:   Name of device file.
- * @dir_name:   Name of mount point.
- * @type:       Name of filesystem type.
- * @flags:      Mount options.
- * @is_enforce: True if it is enforcing mode.
- * @error:      Error value.
+ * @r:        Pointer to "struct ccs_request_info".
+ * @dev_name: Name of device file.
+ * @dir_name: Name of mount point.
+ * @type:     Name of filesystem type.
+ * @flags:    Mount options.
+ * @error:    Error value.
  *
  * Returns 0 if permitted by the administrator's decision, negative value
  * otherwise.
  */
-static int print_error(const char *dev_name, const char *dir_name,
-		       const char *type, const unsigned long flags,
-		       const bool is_enforce, int error)
+static int ccs_print_error(struct ccs_request_info *r,
+			   const char *dev_name, const char *dir_name,
+			   const char *type, const unsigned long flags,
+			   int error)
 {
-	const char *realname1 = ccs_realpath(dev_name);
-	const char *realname2 = ccs_realpath(dir_name);
+	const bool is_enforce = (r->mode == 3);
 	const char *exename = ccs_get_exe();
+	const pid_t pid = (pid_t) sys_getpid();
 	if (!strcmp(type, MOUNT_REMOUNT_KEYWORD)) {
 		printk(KERN_WARNING "SAKURA-%s: mount -o remount %s 0x%lX "
 		       "(pid=%d:exe=%s): Permission denied.\n",
-		       ccs_get_msg(is_enforce),
-		       realname2 ? realname2 : dir_name,
-		       flags, current->pid, exename);
+		       ccs_get_msg(is_enforce), dir_name, flags, pid, exename);
 		if (is_enforce)
-			error = ccs_check_supervisor(NULL,
-						     "# %s is requesting\n"
+			error = ccs_check_supervisor(r, "# %s is requesting\n"
 						     "mount -o remount %s "
 						     "0x%lX\n", exename,
-						     realname2 ? realname2
-						     : dir_name, flags);
+						     dir_name, flags);
 	} else if (!strcmp(type, MOUNT_BIND_KEYWORD)
 		   || !strcmp(type, MOUNT_MOVE_KEYWORD)) {
 		printk(KERN_WARNING "SAKURA-%s: mount %s %s %s 0x%lX "
 		       "(pid=%d:exe=%s): Permission denied.\n",
-		       ccs_get_msg(is_enforce), type,
-		       realname1 ? realname1 : dev_name,
-		       realname2 ? realname2 : dir_name,
-		       flags, current->pid, exename);
+		       ccs_get_msg(is_enforce), type, dev_name, dir_name,
+		       flags, pid, exename);
 		if (is_enforce)
-			error = ccs_check_supervisor(NULL,
-						     "# %s is requesting\n"
+			error = ccs_check_supervisor(r, "# %s is requesting\n"
 						     "mount %s %s %s 0x%lX\n",
-						     exename, type,
-						     realname1 ? realname1 :
-						     dev_name,
-						     realname2 ? realname2 :
+						     exename, type, dev_name,
 						     dir_name, flags);
 	} else if (!strcmp(type, MOUNT_MAKE_UNBINDABLE_KEYWORD) ||
 		   !strcmp(type, MOUNT_MAKE_PRIVATE_KEYWORD) ||
@@ -283,42 +326,33 @@ static int print_error(const char *dev_name, const char *dir_name,
 		   !strcmp(type, MOUNT_MAKE_SHARED_KEYWORD)) {
 		printk(KERN_WARNING "SAKURA-%s: mount %s %s 0x%lX "
 		       "(pid=%d:exe=%s): Permission denied.\n",
-		       ccs_get_msg(is_enforce), type,
-		       realname2 ? realname2 : dir_name,
-		       flags, current->pid, exename);
+		       ccs_get_msg(is_enforce), type, dir_name, flags, pid,
+		       exename);
 		if (is_enforce)
-			error = ccs_check_supervisor(NULL,
-						     "# %s is requesting\n"
+			error = ccs_check_supervisor(r, "# %s is requesting\n"
 						     "mount %s %s 0x%lX",
-						     exename, type,
-						     realname2 ? realname2 :
-						     dir_name, flags);
+						     exename, type, dir_name,
+						     flags);
 	} else {
 		printk(KERN_WARNING "SAKURA-%s: mount -t %s %s %s 0x%lX "
 		       "(pid=%d:exe=%s): Permission denied.\n",
-		       ccs_get_msg(is_enforce), type,
-		       realname1 ? realname1 : dev_name,
-		       realname2 ? realname2 : dir_name,
-		       flags, current->pid, exename);
+		       ccs_get_msg(is_enforce), type, dev_name, dir_name,
+		       flags, pid, exename);
 		if (is_enforce)
-			error = ccs_check_supervisor(NULL,
-						     "# %s is requesting\n"
+			error = ccs_check_supervisor(r, "# %s is requesting\n"
 						     "mount -t %s %s %s "
 						     "0x%lX\n", exename, type,
-						     realname1 ? realname1 :
-						     dev_name,
-						     realname2 ? realname2 :
-						     dir_name, flags);
+						     dev_name, dir_name,
+						     flags);
 	}
 	ccs_free(exename);
-	ccs_free(realname2);
-	ccs_free(realname1);
 	return error;
 }
 
 /**
- * check_mount_permission2 - Check permission for mount() operation.
+ * ccs_check_mount_permission2 - Check permission for mount() operation.
  *
+ * @r:        Pointer to "struct ccs_request_info".
  * @dev_name: Name of device file.
  * @dir_name: Name of mount point.
  * @type:     Name of filesystem type. May be NULL.
@@ -326,16 +360,18 @@ static int print_error(const char *dev_name, const char *dir_name,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int check_mount_permission2(char *dev_name, char *dir_name, char *type,
-				   unsigned long flags)
+static int ccs_check_mount_permission2(struct ccs_request_info *r,
+				       char *dev_name, char *dir_name,
+				       char *type, unsigned long flags)
 {
-	const u8 mode = ccs_check_flags(CCS_SAKURA_RESTRICT_MOUNT);
-	const bool is_enforce = (mode == 3);
-	int error = -EPERM;
-	if (!mode)
-		return 0;
+	const bool is_enforce = (r->mode == 3);
+	int error;
+ retry:
+	error = -EPERM;
 	if (!type)
 		type = "<NULL>";
+	if (!dev_name)
+		dev_name = "<NULL>";
 	if ((flags & MS_MGC_MSK) == MS_MGC_VAL)
 		flags &= ~MS_MGC_MSK;
 	switch (flags & (MS_REMOUNT | MS_MOVE | MS_BIND)) {
@@ -369,42 +405,47 @@ static int check_mount_permission2(char *dev_name, char *dir_name, char *type,
 		return -EINVAL;
 	}
 	if (flags & MS_REMOUNT) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_REMOUNT_KEYWORD,
-						flags & ~MS_REMOUNT);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+						    MOUNT_REMOUNT_KEYWORD,
+						    flags & ~MS_REMOUNT);
 	} else if (flags & MS_MOVE) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_MOVE_KEYWORD,
-						flags & ~MS_MOVE);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+						    MOUNT_MOVE_KEYWORD,
+						    flags & ~MS_MOVE);
 	} else if (flags & MS_BIND) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_BIND_KEYWORD,
-						flags & ~MS_BIND);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+						    MOUNT_BIND_KEYWORD,
+						    flags & ~MS_BIND);
 	} else if (flags & MS_UNBINDABLE) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_MAKE_UNBINDABLE_KEYWORD,
-						flags & ~MS_UNBINDABLE);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+					    MOUNT_MAKE_UNBINDABLE_KEYWORD,
+						    flags & ~MS_UNBINDABLE);
 	} else if (flags & MS_PRIVATE) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_MAKE_PRIVATE_KEYWORD,
-						flags & ~MS_PRIVATE);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+						    MOUNT_MAKE_PRIVATE_KEYWORD,
+						    flags & ~MS_PRIVATE);
 	} else if (flags & MS_SLAVE) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_MAKE_SLAVE_KEYWORD,
-						flags & ~MS_SLAVE);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+						    MOUNT_MAKE_SLAVE_KEYWORD,
+						    flags & ~MS_SLAVE);
 	} else if (flags & MS_SHARED) {
-		error = check_mount_permission2(dev_name, dir_name,
-						MOUNT_MAKE_SHARED_KEYWORD,
-						flags & ~MS_SHARED);
+		error = ccs_check_mount_permission2(r, dev_name, dir_name,
+						    MOUNT_MAKE_SHARED_KEYWORD,
+						    flags & ~MS_SHARED);
 	} else {
-		struct mount_entry *ptr;
+		struct ccs_mount_entry *ptr;
 		struct file_system_type *fstype = NULL;
+		const char *requested_type = NULL;
 		const char *requested_dir_name = NULL;
 		const char *requested_dev_name = NULL;
-		struct path_info rdev;
-		struct path_info rdir;
+		struct ccs_path_info rdev;
+		struct ccs_path_info rdir;
 		int need_dev = 0;
-
+		requested_type = ccs_encode(type);
+		if (!requested_type) {
+			error = -ENOMEM;
+			goto cleanup;
+		}
 		requested_dir_name = ccs_realpath(dir_name);
 		if (!requested_dir_name) {
 			error = -ENOENT;
@@ -415,44 +456,41 @@ static int check_mount_permission2(char *dev_name, char *dir_name, char *type,
 
 		/* Compare fs name. */
 		if (!strcmp(type, MOUNT_REMOUNT_KEYWORD)) {
-			/* Needn't to resolve dev_name */
+			/* dev_name is ignored. */
 		} else if (!strcmp(type, MOUNT_MAKE_UNBINDABLE_KEYWORD) ||
 			   !strcmp(type, MOUNT_MAKE_PRIVATE_KEYWORD) ||
 			   !strcmp(type, MOUNT_MAKE_SLAVE_KEYWORD) ||
 			   !strcmp(type, MOUNT_MAKE_SHARED_KEYWORD)) {
-			/* Needn't to resolve dev_name */
+			/* dev_name is ignored. */
 		} else if (!strcmp(type, MOUNT_BIND_KEYWORD) ||
 			   !strcmp(type, MOUNT_MOVE_KEYWORD)) {
+			need_dev = -1; /* dev_name is a directory */
+		} else {
+			fstype = get_fs_type(type);
+			if (!fstype) {
+				error = -ENODEV;
+				goto cleanup;
+			}
+			if (fstype->fs_flags & FS_REQUIRES_DEV)
+				/* dev_name is a block device file. */
+				need_dev = 1;
+		}
+		if (need_dev) {
 			requested_dev_name = ccs_realpath(dev_name);
 			if (!requested_dev_name) {
 				error = -ENOENT;
 				goto cleanup;
 			}
-			rdev.name = requested_dev_name;
-			ccs_fill_path_info(&rdev);
-			/* dev_name is a directory */
-			need_dev = -1;
 		} else {
-			fstype = get_fs_type(type);
-			if (fstype) {
-				if (fstype->fs_flags & FS_REQUIRES_DEV) {
-					requested_dev_name
-						= ccs_realpath(dev_name);
-					if (!requested_dev_name) {
-						error = -ENOENT;
-						goto cleanup;
-					}
-					rdev.name = requested_dev_name;
-					ccs_fill_path_info(&rdev);
-					/* dev_name is a block device file */
-					need_dev = 1;
-				}
-			} else {
-				error = -ENODEV;
+			requested_dev_name = ccs_encode(dev_name);
+			if (!requested_dev_name) {
+				error = -ENOMEM;
 				goto cleanup;
 			}
 		}
-		list1_for_each_entry(ptr, &mount_list, list) {
+		rdev.name = requested_dev_name;
+		ccs_fill_path_info(&rdev);
+		list1_for_each_entry(ptr, &ccs_mount_list, list) {
 			if (ptr->is_deleted)
 				continue;
 
@@ -465,35 +503,41 @@ static int check_mount_permission2(char *dev_name, char *dir_name, char *type,
 				continue;
 
 			/* Compare mount point. */
-			if (ccs_path_matches_pattern(&rdir, ptr->dir_name) == 0)
+			if (!ccs_path_matches_pattern(&rdir, ptr->dir_name))
 				continue;
 
 			/* Compare device name. */
-			if (requested_dev_name &&
-			    ccs_path_matches_pattern(&rdev, ptr->dev_name) == 0)
+			if (need_dev &&
+			    !ccs_path_matches_pattern(&rdev, ptr->dev_name))
 				continue;
 
 			/* OK. */
 			error = 0;
-			print_success(requested_dev_name, requested_dir_name,
-				      type, flags, need_dev);
+			ccs_print_success(requested_dev_name,
+					  requested_dir_name,
+					  requested_type, flags, need_dev);
 			break;
 		}
 		if (error)
-			error = print_error(dev_name, dir_name, type, flags,
-					    is_enforce, error);
-		if (error && mode == 1)
-			update_mount_acl(need_dev ?
-					 requested_dev_name : dev_name,
-					 requested_dir_name, type, flags, 0);
+			error = ccs_print_error(r, requested_dev_name,
+						requested_dir_name,
+						requested_type,
+						flags, error);
+		if (error && r->mode == 1)
+			ccs_update_mount_acl(requested_dev_name,
+					     requested_dir_name,
+					     requested_type, flags, false);
  cleanup:
 		ccs_free(requested_dev_name);
 		ccs_free(requested_dir_name);
 		if (fstype)
 			put_filesystem(fstype);
+		ccs_free(requested_type);
 	}
 	if (!is_enforce)
 		error = 0;
+	if (error == 1)
+		goto retry;
 	return error;
 }
 
@@ -506,17 +550,22 @@ static int check_mount_permission2(char *dev_name, char *dir_name, char *type,
  * @flags:    Mount options.
  *
  * Returns 0 on success, negative value otherwise.
- *
- * This is a wrapper to allow use of 1.4.x patch for 1.5.x.
  */
 int ccs_check_mount_permission(char *dev_name, char *dir_name, char *type,
 			       const unsigned long *flags)
 {
-	return check_mount_permission2(dev_name, dir_name, type, *flags);
+	struct ccs_request_info r;
+	if (!ccs_can_sleep())
+		return 0;
+	ccs_init_request_info(&r, NULL, CCS_RESTRICT_MOUNT);
+	if (!r.mode)
+		return 0;
+	return ccs_check_mount_permission2(&r, dev_name, dir_name, type,
+					   *flags);
 }
 
 /**
- * ccs_write_mount_policy - Write "struct mount_entry" list.
+ * ccs_write_mount_policy - Write "struct ccs_mount_entry" list.
  *
  * @data:      String to parse.
  * @is_delete: True if it is a delete request.
@@ -550,11 +599,11 @@ int ccs_write_mount_policy(char *data, const bool is_delete)
 	*cp = '\0';
 	fs = cp2;
 	flags = simple_strtoul(cp + 1, NULL, 0);
-	return update_mount_acl(dev, dir, fs, flags, is_delete);
+	return ccs_update_mount_acl(dev, dir, fs, flags, is_delete);
 }
 
 /**
- * ccs_read_mount_policy - Read "struct mount_entry" list.
+ * ccs_read_mount_policy - Read "struct ccs_mount_entry" list.
  *
  * @head: Pointer to "struct ccs_io_buffer".
  *
@@ -563,9 +612,9 @@ int ccs_write_mount_policy(char *data, const bool is_delete)
 bool ccs_read_mount_policy(struct ccs_io_buffer *head)
 {
 	struct list1_head *pos;
-	list1_for_each_cookie(pos, head->read_var2, &mount_list) {
-		struct mount_entry *ptr;
-		ptr = list1_entry(pos, struct mount_entry, list);
+	list1_for_each_cookie(pos, head->read_var2, &ccs_mount_list) {
+		struct ccs_mount_entry *ptr;
+		ptr = list1_entry(pos, struct ccs_mount_entry, list);
 		if (ptr->is_deleted)
 			continue;
 		if (!ccs_io_printf(head, KEYWORD_ALLOW_MOUNT "%s %s %s 0x%lX\n",
